#!/bin/bash
#
# This script assumes that
# (1) You have a python3 environment supporting NumPy, Matplotlib, CartoPy and ecCodes
# (2) You have AAPP v8.15 or higher, with the aapp_BUFR_quicklook.py utility
#
# For more detail, see the AAPP-AWS User Manual, at https://nwp-saf.eumetsat.int/site/software/aapp/documentation/

#### CONSTANTS

THIS_DIR=$(cd $(dirname ${BASH_SOURCE[0]}); echo ${PWD})
OUTPUTS_DIR=${THIS_DIR}/outputs
FILE1B="AWS_20250505081550_20250505095240_nc-to-bufr_l1b.bufr"
FILE1C="AWS_20250505081550_20250505095240_nc-to-bufr_l1c.band3.bufr_nl.bufr"
# Plotting parameters
CHANNEL=9
BAND=2
LAT_RANGE="0 60"
LON_RANGE="30 70"


#### MAIN

echo "Running plot_aws.sh"

# Check availability of plotting tool
which aapp_BUFR_quicklook.py &> /dev/null
if [ $? != 0 ]; then
  if [ "${AAPP_AWS_HOME}" ]; then
    source ${AAPP_AWS_HOME}/aapp_aws_env.sh
    which aapp_BUFR_quicklook.py &> /dev/null
    if [ $? != 0 ]; then
      echo "Cannot find aapp_BUFR_quicklook.py within ${AAPP_AWS_HOME}"
      exit 1
    fi
  else
    echo "Please define AAPP_AWS_HOME or make sure aapp_BUFR_quicklook.py is in your PATH"
    exit 1
  fi
fi

# cd to directory containing AWS BUFR files
if [ ! -d ${OUTPUTS_DIR} ]; then
  echo "Error: no outputs directory"
  exit 1
fi
cd ${OUTPUTS_DIR}

echo -e "\nPlotting AWS l1b file..."
symbol_size=4
aapp_BUFR_quicklook.py -i "${FILE1B}" -c "${CHANNEL}" -b "${BAND}" -r "${LAT_RANGE} ${LON_RANGE}" -s "${symbol_size}"

echo -e "\nPlotting AWS l1c file..."
symbol_size=12
aapp_BUFR_quicklook.py -i "${FILE1C}" -c "${CHANNEL}" -r "${LAT_RANGE} ${LON_RANGE}" -s "${symbol_size}"

echo -e "\nFinished running plot_aws.sh"
